summaryrefslogtreecommitdiff
path: root/indra/newview/llpanelpicks.cpp
diff options
context:
space:
mode:
authorMerov Linden <merov@lindenlab.com>2011-11-02 13:44:18 -0700
committerMerov Linden <merov@lindenlab.com>2011-11-02 13:44:18 -0700
commit353f7ea61873d9f35685a59b4102899b4a9e596e (patch)
tree3ca2964682d7e5e23b7a178a854c567c7c5384d9 /indra/newview/llpanelpicks.cpp
parent139c13bdc0387f50d9f3a71737a95a4585bc471c (diff)
parent334d8f4076b4045e8fd4ede5fd9d31f0b185ded4 (diff)
Pull from richard/viewer-experience
Diffstat (limited to 'indra/newview/llpanelpicks.cpp')
-rwxr-xr-xindra/newview/llpanelpicks.cpp21
1 files changed, 10 insertions, 11 deletions
diff --git a/indra/newview/llpanelpicks.cpp b/indra/newview/llpanelpicks.cpp
index 72c6be4c79..04e78e04e3 100755
--- a/indra/newview/llpanelpicks.cpp
+++ b/indra/newview/llpanelpicks.cpp
@@ -130,11 +130,11 @@ public:
void createPick()
{
- LLSD params;
- params["id"] = gAgent.getID();
- params["open_tab_name"] = "panel_picks";
- params["show_tab_panel"] = "create_pick";
- LLFloaterSidePanelContainer::showPanel("my_profile", params);
+ // open the new pick panel on the Picks floater
+ LLFloater* picks_floater = LLFloaterReg::showInstance("picks");
+
+ LLPanelPicks* picks = picks_floater->findChild<LLPanelPicks>("panel_picks");
+ picks->createNewPick();
}
void editPick(LLPickData* pick_info)
@@ -247,12 +247,11 @@ public:
void createClassified()
{
- // open the new classified panel on the Me > Picks sidetray
- LLSD params;
- params["id"] = gAgent.getID();
- params["open_tab_name"] = "panel_picks";
- params["show_tab_panel"] = "create_classified";
- LLFloaterSidePanelContainer::showPanel("my_profile", params);
+ // open the new classified panel on the Picks floater
+ LLFloater* picks_floater = LLFloaterReg::showInstance("picks");
+
+ LLPanelPicks* picks = picks_floater->findChild<LLPanelPicks>("panel_picks");
+ picks->createNewClassified();
}
void openClassified(LLAvatarClassifiedInfo* c_info)